##
##  opendbx.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2010 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         opendbx
Summary:      Database Access Abstraction Library
URL:          http://www.linuxnetworks.de/opendbx/
Vendor:       Norbert Sendetzky
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      LGPL
Version:      1.4.5
Release:      20100421

#   package options
%option       with_sqlite  yes
%option       with_mysql   yes
%option       with_pgsql   yes

#   list of sources
Source0:      http://www.linuxnetworks.de/opendbx/download/opendbx-%{version}.tar.gz
Patch0:       opendbx.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101, gcc
PreReq:       OpenPKG, openpkg >= 20100101
%if "%{with_sqlite}" == "yes"
BuildPreReq:  sqlite, pkgconfig
PreReq:       sqlite
%endif
%if "%{with_mysql}" == "yes"
BuildPreReq:  mysql
PreReq:       mysql
%endif
%if "%{with_pgsql}" == "yes"
BuildPreReq:  postgresql
PreReq:       postgresql
%endif

%description
    OpenDBX is an extremely lightweight but extensible C library for
    accessing databases with a single API. It provides a clean and
    simple interface across all supported databases that leads to an
    elegant code design automatically.

%track
    prog opendbx = {
        version   = %{version}
        url       = http://www.linuxnetworks.de/doc/index.php/OpenDBX_Download
        regex     = opendbx-(\d+\.[2468]\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    export CC="%{l_cc}"
    export CFLAGS="%{l_cflags -O}"
    export CPPFLAGS="%{l_cppflags}"
    export LDFLAGS="%{l_ldflags}"
    export LIBS=""
    backends=""
%if "%{with_sqlite}" == "yes"
    backends="$backends sqlite3"
    CPPFLAGS="$CPPFLAGS `pkg-config sqlite3 --cflags`"
    LDFLAGS="$LDFLAGS `pkg-config sqlite3 --libs-only-L`"
    LIBS="$LIBS `pkg-config sqlite3 --libs-only-l`"
%endif
%if "%{with_mysql}" == "yes"
    backends="$backends mysql"
    CPPFLAGS="$CPPFLAGS `mysql_config --include`"
    LIBS="$LIBS `mysql_config --libs`"
%endif
%if "%{with_pgsql}" == "yes"
    backends="$backends pgsql"
    CPPFLAGS="$CPPFLAGS `pg_config --cppflags` %{l_cppflags postgresql}"
    LDFLAGS="$LDFLAGS `pg_config --ldflags`"
    LIBS="$LIBS `pg_config --libs`"
%endif
    ./configure \
        --prefix=%{l_prefix} \
        --with-backends="$backends" \
        --disable-nls
    %{l_make} %{l_mflags}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/opendbx/lib*.a
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/opendbx/lib*.la
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/libopendbx.so*
    rm -f $RPM_BUILD_ROOT%{l_prefix}/lib/libopendbx.la
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

